@@ -8,7 +8,8 @@ has_other_issues_details <- function(parsed, ...) {
     issue_type <- xml2::xml_text(other_issues_pth)
     issue_url <- xml2::xml_text(xml2::xml_find_all(other_issues_pth, "@href"))
     tibble::tibble(
-      result = "other_issue", check = issue_type,
+      result = "other_issue",
+      check = issue_type,
       flavors = NA_character_,
       message = paste0("See: <", issue_url, ">")
     )
@@ -26,46 +27,68 @@ cran_details_from_web <- function(pkg, ...) {
   parsed <- read_cran_web_from_pkg(pkg)
   issue_test <- has_other_issues_details(parsed)
 
-  all_p <- mapply(function(x, pkg_nm) {
-    p <- xml2::xml_find_all(x, ".//p")
-    p <- strsplit(xml2::xml_text(x), "\n")
-    p <- unlist(p)
-    p <- p[nzchar(p)]
-    p <- gsub(intToUtf8(160), " ", p)
-    chk_idx <- grep("^Check:", p)
-    vrs_idx <- grep("^Version:", p)
-    res_idx <- grep("^Result:", p)
-    flv_idx <- grep("^Flavors?:", p)
-    if (!identical(length(chk_idx), length(res_idx)) &&
-          !identical(length(chk_idx), length(flv_idx))) {
-      stop("File an issue on Github indicating the name of your package.")
-    }
-    msg <- mapply(function(c, v, r, f) {
-      tibble::tibble(
-        version = gsub("^Version: ", "", p[v]),
-        result = gsub("^Result: ", "", p[r]),
-        check = gsub("^Check: ", "", p[c]),
-        flavors = gsub("^Flavors?: ", "", p[f]),
-        n_flavors = length(unlist(gregexpr(",", p[f]))) + 1,
-        message = paste(gsub("^\\s+", "     ", p[(r + 1):(f - 1)]), collapse = "\n")
+  all_p <- mapply(
+    function(x, pkg_nm) {
+      p <- xml2::xml_find_all(x, ".//p")
+      p <- strsplit(xml2::xml_text(x), "\n")
+      p <- unlist(p)
+      p <- p[nzchar(p)]
+      p <- gsub(intToUtf8(160), " ", p)
+      chk_idx <- grep("^Check:", p)
+      vrs_idx <- grep("^Version:", p)
+      res_idx <- grep("^Result:", p)
+      flv_idx <- grep("^Flavors?:", p)
+      if (
+        !identical(length(chk_idx), length(res_idx)) &&
+          !identical(length(chk_idx), length(flv_idx))
+      ) {
+        stop("File an issue on Github indicating the name of your package.")
+      }
+      msg <- mapply(
+        function(c, v, r, f) {
+          tibble::tibble(
+            version = gsub("^Version: ", "", p[v]),
+            result = gsub("^Result: ", "", p[r]),
+            check = gsub("^Check: ", "", p[c]),
+            flavors = gsub("^Flavors?: ", "", p[f]),
+            n_flavors = length(unlist(gregexpr(",", p[f]))) + 1,
+            message = paste(
+              gsub("^\\s+", "     ", p[(r + 1):(f - 1)]),
+              collapse = "\n"
+            )
+          )
+        },
+        chk_idx,
+        vrs_idx,
+        res_idx,
+        flv_idx,
+        SIMPLIFY = FALSE,
+        USE.NAMES = FALSE
       )
-    }, chk_idx, vrs_idx, res_idx, flv_idx, SIMPLIFY = FALSE, USE.NAMES = FALSE)
 
-    r <- do.call("rbind", msg)
-    if (!is.null(r)) {
-      r <- cbind(package = rep(pkg_nm, nrow(r)), r, stringsAsFactors = FALSE)
-    } else {
-      r <- tibble::add_row(default_cran_details,
-        package = pkg_nm,
-        version = paste(unique(get_cran_table(parsed[pkg_nm])$version), collapse = ", "),
-        result = "OK",
-        check = "",
-        flavors = "",
-        n_flavors = n_cran_flavors(),
-        message = ""
-      )
-    }
-  }, parsed, names(parsed), SIMPLIFY = FALSE)
+      r <- do.call("rbind", msg)
+      if (!is.null(r)) {
+        r <- cbind(package = rep(pkg_nm, nrow(r)), r, stringsAsFactors = FALSE)
+      } else {
+        r <- tibble::add_row(
+          default_cran_details,
+          package = pkg_nm,
+          version = paste(
+            unique(get_cran_table(parsed[pkg_nm])$version),
+            collapse = ", "
+          ),
+          result = "OK",
+          check = "",
+          flavors = "",
+          n_flavors = n_cran_flavors(),
+          message = ""
+        )
+      }
+    },
+    parsed,
+    names(parsed),
+    SIMPLIFY = FALSE
+  )
 
   res <- do.call("rbind", all_p)
 
@@ -84,7 +107,6 @@ cran_details_from_web <- function(pkg, ...) {
 }
 
 
-
 ##' @importFrom tibble tibble
 cran_details_from_crandb <- function(pkg, ...) {
   dt <- get_cran_rds_file("details", ...)
@@ -110,7 +132,8 @@ cran_details_from_crandb <- function(pkg, ...) {
         dt_c <- dt_v[dt_v$check == .c, ]
         for (.s in unique(dt_c$status)) {
           dt_s <- dt_c[dt_c$status == .s, ]
-          .res <- tibble::add_row(.res,
+          .res <- tibble::add_row(
+            .res,
             package = .p,
             version = .v,
             result = .s %~~% "",
@@ -158,8 +181,7 @@ cran_details_from_crandb <- function(pkg, ...) {
 ##'     \code{FAIL}, \code{NOTE}, or other issues).
 ##' @export
 ##' @importFrom cli style_bold
-cran_details <- function(pkg, src = c("website", "crandb"),
-                         ...) {
+cran_details <- function(pkg, src = c("website", "crandb"), ...) {
   if (!is.character(pkg)) {
     stop(sQuote("pkg"), " is not a string.", call. = FALSE)
   }
@@ -221,7 +243,12 @@ filter_pkg_ok <- function(res) {
 ##' @export
 ##' @importFrom cli col_green
 ##' @importFrom cli symbol
-summary.cran_details <- function(object, show_log = TRUE, print_ok = TRUE, ...) {
+summary.cran_details <- function(
+  object,
+  show_log = TRUE,
+  print_ok = TRUE,
+  ...
+) {
   res_ok <- filter_pkg_ok(object)
 
   if (nrow(res_ok) > 0 && print_ok) {
@@ -242,20 +269,30 @@ summary.cran_details <- function(object, show_log = TRUE, print_ok = TRUE, ...)
       } else {
         msg <- character(0)
       }
-      cat( ## Type of CRAN message
+      cat(
+        ## Type of CRAN message
         cmpt$color(paste0(
-          cmpt$symbol, " ",
+          cmpt$symbol,
+          " ",
           cli::style_bold(paste0(package, " - ", result)),
-          ": ", check
-        )), "\n",
+          ": ",
+          check
+        )),
+        "\n",
         ## Flavors concerned
-        render_flavors(flavors), "\n",
+        render_flavors(flavors),
+        "\n",
         ## Optionally the log output
-        msg, "\n\n",
+        msg,
+        "\n\n",
         sep = ""
       )
-    }, res_not_ok$package, tolower(res_not_ok$result), res_not_ok$check,
-    res_not_ok$flavors, res_not_ok$message
+    },
+    res_not_ok$package,
+    tolower(res_not_ok$result),
+    res_not_ok$check,
+    res_not_ok$flavors,
+    res_not_ok$message
   )
 
   invisible(object)
@@ -264,8 +301,13 @@ summary.cran_details <- function(object, show_log = TRUE, print_ok = TRUE, ...)
 
 ##' @export
 ##' @rdname cran_details
-summary_cran_details <- function(pkg, src = c("website", "crandb"),
-                                 show_log = TRUE, print_ok = TRUE, ...) {
+summary_cran_details <- function(
+  pkg,
+  src = c("website", "crandb"),
+  show_log = TRUE,
+  print_ok = TRUE,
+  ...
+) {
   res <- cran_details(pkg = pkg, src = src, ...)
   summary(res, show_log = show_log, print_ok = print_ok)
 }
